@@ -3,7 +3,7 @@
 use strict;
 use warnings;
 
-use Mo::utils::Language qw(check_language_639_2);
+use Mo::utils::Language 0.05 qw(check_language_639_2);
 
 my $self = {
         'key' => 'eng',
